/*******************************************************************************
* File Name: hts.c
*
* Version: 1.0
*
* Description:
*  This file contains HTS callback handler function.
*
* Hardware Dependency:
*  CY8CKIT-042 BLE
* 
********************************************************************************
* Copyright 2016, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "common.h"
#include "hts.h"
#include "Board_Temperature.h "

uint16 temperatureMeasure = 0u;
uint32 temperatureTimer = 1u;

uint16 initialMeasurementInterval = 10;
uint8 measure = ENABLED; 

/* Byte order: 
*   Flags
*   Temperature in float format (MSB 8 bits - exponent, LSB 24 bits - mantissa) 
*/
uint8 temp_data[HTS_TEMP_DATA_MIN_SIZE] = {0u, 0u, 0u, 0u, 0u};


/*******************************************************************************
* Function Name: HtsCallBack()
********************************************************************************
*
* Summary:
*   This is an event callback function to receive service specific events from 
*   Health Thermometer Service.
*
* Parameters:
*  event - the event code
*  *eventParam - the event parameters
*
* Return:
*  None.
*
*******************************************************************************/
void HtsCallBack(uint32 event, void *eventParam)
{
    uint8 locCharIndex;
    locCharIndex = ((CYBLE_HTS_CHAR_VALUE_T *)eventParam)->charIndex;
    DBG_PRINTF("HTS event: %lx, ", event);

    switch(event)
    {
        case CYBLE_EVT_HTSS_NOTIFICATION_ENABLED:
            break;
        case CYBLE_EVT_HTSS_NOTIFICATION_DISABLED:
            break;
        case CYBLE_EVT_HTSS_INDICATION_ENABLED:
            DBG_PRINTF("CYBLE_EVT_HTSS_INDICATION_ENABLED: char: %x\r\n", locCharIndex);
            if(locCharIndex == CYBLE_HTS_TEMP_MEASURE)
            {
                temperatureMeasure = ENABLED;
                measure = ENABLED;
                temp_data[0] = 0u;
            }
            break;
        case CYBLE_EVT_HTSS_INDICATION_DISABLED:
            DBG_PRINTF("CYBLE_EVT_HTSS_INDICATION_DISABLED: char: %x\r\n", locCharIndex);
            if(locCharIndex == CYBLE_HTS_TEMP_MEASURE)
            {
                temperatureMeasure = DISABLED;
            }
            break;
        case CYBLE_EVT_HTSS_INDICATION_CONFIRMED:
            DBG_PRINTF("CYBLE_EVT_HTSS_INDICATION_CONFIRMED\r\n");
            break;
        case CYBLE_EVT_HTSS_CHAR_WRITE:
            DBG_PRINTF("CYBLE_EVT_HTSS_CHAR_WRITE: %x ", locCharIndex);
            ShowValue(((CYBLE_HTS_CHAR_VALUE_T *)eventParam)->value);
            if(locCharIndex == CYBLE_HTS_MEASURE_INTERVAL)
            {
                uint16 interval;
                interval = CyBle_Get16ByPtr(((CYBLE_HTS_CHAR_VALUE_T *)eventParam)->value->val);
                
                /* Store new interval value */
                initialMeasurementInterval = interval;
                if(interval != 0u)
                {
                    /* Reset the measurement interval and start the measurement process. */
                    temperatureTimer = 1u;
                    mainTimer++;
                }
            }
            break;
        case CYBLE_EVT_HTSC_NOTIFICATION:
            break;
        case CYBLE_EVT_HTSC_INDICATION:
            break;
        case CYBLE_EVT_HTSC_READ_CHAR_RESPONSE:
            break;
        case CYBLE_EVT_HTSC_WRITE_CHAR_RESPONSE:
            break;
        case CYBLE_EVT_HTSC_READ_DESCR_RESPONSE:
            break;
        case CYBLE_EVT_HTSC_WRITE_DESCR_RESPONSE:
            break;
		default:
            DBG_PRINTF("Not supported event\r\n");
			break;
    }
}


/*******************************************************************************
* Function Name: MeasureTemperature()
********************************************************************************
*
* Summary:
*   This function measures the die temperature and sends it to the client.
*
*******************************************************************************/
void MeasureTemperature(void)
{
	 
    double temperatureValue;
    static double temperatureCelsius;
    CYBLE_API_RESULT_T apiResult;
   
    
    /* Do not measure temperature when 0 interval is set */
    if((initialMeasurementInterval != 0u) && (--temperatureTimer == 0u)) 
    {
        temperatureTimer = initialMeasurementInterval;
        
        temperatureValue = 0;

        
        temperatureCelsius =  Read_Board_Temp_Data();
     
        if(temperatureCelsius>0)
        {
            
            temperatureValue =  (temperatureCelsius );
            
        }
        else
        {
             temperatureValue =  (temperatureCelsius *10);
        }
       
        
        Set32ByPtr(temp_data + 1u, (float)temperatureValue);
        
         

        /* Send temperature to client */
        apiResult = CyBle_HtssSendIndication(cyBle_connHandle, CYBLE_HTS_TEMP_MEASURE, 
                        sizeof(temperatureValue), temp_data);
        if(apiResult != CYBLE_ERROR_OK)
        {
          
            temperatureMeasure = DISABLED;
        }
        else
        {
        
            
        }
       
    }
}

/* [] END OF FILE */

